@@ -1,6 +1,6 @@
 from functools import wraps
 
-from django.conf import settings
+from django.conf import settings as django_settings
 from django.http.response import Http404
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext
@@ -9,12 +9,11 @@ from django.urls import NoReverseMatch
 
 from pyston.conf import settings as pyston_settings
 from pyston.forms import rest_modelform_factory
-from pyston.exception import (RESTException, MimerDataException, NotAllowedException, UnsupportedMediaTypeException,
+from pyston.exception import (RestException, MimerDataException, NotAllowedException, UnsupportedMediaTypeException,
                               ResourceNotFoundException, NotAllowedMethodException, DuplicateEntryException,
                               ConflictException, DataInvalidException, UnauthorizedException)
-from pyston.resource import BaseResource, BaseModelResource, DefaultRESTModelResource
-from pyston.response import RESTErrorResponse, RESTErrorsResponse
-from pyston.utils import rfs
+from pyston.resource import BaseResource, DjangoResource
+from pyston.response import RestErrorResponse, RestErrorsResponse
 
 from chamber.shortcuts import get_object_or_none
 from chamber.utils import transaction
@@ -24,16 +23,17 @@ from is_core.auth.permissions import (
     CoreCreateAllowed, AllowAny, DEFAULT_PERMISSION
 )
 from is_core.auth.views import FieldPermissionViewMixin
-from is_core.config import settings
-from is_core.exceptions.response import (HTTPBadRequestResponseException, HTTPUnsupportedMediaTypeResponseException,
-                                         HTTPMethodNotAllowedResponseException, HTTPDuplicateResponseException,
-                                         HTTPForbiddenResponseException)
+from is_core.exceptions.response import (HttpBadRequestResponseException, HttpUnsupportedMediaTypeResponseException,
+                                         HttpMethodNotAllowedResponseException, HttpDuplicateResponseException,
+                                         HttpForbiddenResponseException)
 from is_core.forms.models import smartmodelform_factory
-from is_core.patterns import RESTPattern, patterns
+from is_core.patterns import RestPattern, patterns
 from is_core.utils import get_field_label_from_path, METHOD_OBJ_STR_NAME, LOOKUP_SEP
 
+from .filters import CoreDjangoFilterManager
 
-class RESTPermissionsMixin:
+
+class PermissionsResourceMixin:
 
     permission = IsAuthenticated()
     csrf_exempt = False
@@ -92,7 +92,7 @@ class RESTPermissionsMixin:
                 raise
 
 
-class RESTObjectPermissionsMixin(RESTPermissionsMixin):
+class PermissionsModelResourceMixin(PermissionsResourceMixin):
 
     can_create_obj = True
     can_read_obj = True
@@ -124,7 +124,7 @@ class RESTObjectPermissionsMixin(RESTPermissionsMixin):
         )
 
 
-class RESTResourceMixin:
+class CoreResourceMixin:
 
     register = False
     abstract = True
@@ -132,7 +132,7 @@ class RESTResourceMixin:
     def dispatch(self, request, *args, **kwargs):
         if hasattr(self, 'core'):
             self.core.init_rest_request(request)
-        return super(RESTResourceMixin, self).dispatch(request, *args, **kwargs)
+        return super().dispatch(request, *args, **kwargs)
 
     @classmethod
     def __init_core__(cls, core, pattern):
@@ -144,19 +144,19 @@ class RESTResourceMixin:
         Trasform pyston exceptions to Is-core exceptions and raise it
         """
         response_exceptions = {
-            MimerDataException: HTTPBadRequestResponseException,
-            NotAllowedException: HTTPForbiddenResponseException,
-            UnsupportedMediaTypeException: HTTPUnsupportedMediaTypeResponseException,
+            MimerDataException: HttpBadRequestResponseException,
+            NotAllowedException: HttpForbiddenResponseException,
+            UnsupportedMediaTypeException: HttpUnsupportedMediaTypeResponseException,
             Http404: Http404,
             ResourceNotFoundException: Http404,
-            NotAllowedMethodException: HTTPMethodNotAllowedResponseException,
-            DuplicateEntryException: HTTPDuplicateResponseException,
-            ConflictException: HTTPDuplicateResponseException,
+            NotAllowedMethodException: HttpMethodNotAllowedResponseException,
+            DuplicateEntryException: HttpDuplicateResponseException,
+            ConflictException: HttpDuplicateResponseException,
         }
         response_exception = response_exceptions.get(type(exception))
         if response_exception:
             raise response_exception
-        return super(RESTResourceMixin, self)._get_error_response(exception)
+        return super()._get_error_response(exception)
 
     @classmethod
     def get_method_returning_field_value(cls, field_name):
@@ -179,7 +179,7 @@ class RESTResourceMixin:
         return None
 
 
-class RESTModelCoreResourcePermissionsMixin(RESTObjectPermissionsMixin):
+class PermissionsModelCoreResourceMixin(PermissionsModelResourceMixin):
 
     pk_name = 'pk'
 
@@ -213,32 +213,11 @@ class RESTModelCoreResourcePermissionsMixin(RESTObjectPermissionsMixin):
             return None
 
 
-class RESTModelCoreMixin(RESTModelCoreResourcePermissionsMixin):
-
-    def _get_queryset(self):
-        return self.core.get_queryset(self.request)
-
-    def _get_pk(self):
-        return self.kwargs.get(self.pk_name)
-
-    def _get_obj_or_none(self, pk=None):
-        if pk or self._get_pk():
-            return get_object_or_none(self._get_queryset(), pk=(pk or self._get_pk()))
-        else:
-            return None
-
-    def _get_obj_or_404(self, pk=None):
-         obj = self._get_obj_or_none(pk)
-         if not obj:
-             raise Http404
-         return obj
-
-
-class RESTResource(RESTPermissionsMixin, RESTResourceMixin, BaseResource):
+class CoreResource(PermissionsResourceMixin, CoreResourceMixin, BaseResource):
     pass
 
 
-class EntryPointResource(RESTResource):
+class EntryPointResource(CoreResource):
 
     allowed_methods = ('get', 'head', 'options')
     permission = AllowAny()
@@ -246,7 +225,7 @@ class EntryPointResource(RESTResource):
     def get(self):
         out = {}
         for pattern_name, pattern in patterns.items():
-            if isinstance(pattern, RESTPattern):
+            if isinstance(pattern, RestPattern):
                 try:
                     url = pattern.get_url_string(self.request)
                     allowed_methods = pattern.get_allowed_methods(self.request, None)
@@ -258,22 +237,90 @@ class EntryPointResource(RESTResource):
         return out
 
 
-class RESTModelResource(FieldPermissionViewMixin, RESTModelCoreMixin, RESTResourceMixin, BaseModelResource):
+class SmartFormDjangoResource(DjangoResource):
 
-    form_class = None
-    field_labels = None
-    abstract = True
-    filters = {}
-    default_fields_extension = None
+    def _generate_form_class(self, inst, exclude=None):
+        exclude = [] if exclude is None else exclude
+        exclude = list(self._get_exclude(inst)) + exclude
+        form_class = self._get_form_class(inst)
+        fields = self._get_form_fields(inst)
+        if hasattr(form_class, '_meta') and form_class._meta.exclude:
+            exclude.extend(form_class._meta.exclude)
+        return rest_modelform_factory(
+            self.model,
+            form=form_class,
+            form_factory=smartmodelform_factory,
+            resource_typemapper=self.resource_typemapper,
+            auto_related_direct_fields=pyston_settings.AUTO_RELATED_DIRECT_FIELDS,
+            auto_related_reverse_fields=pyston_settings.AUTO_RELATED_REVERSE_FIELDS,
+            request=self.request,
+            exclude=exclude,
+            fields=fields,
+            formfield_callback=self.formfield_for_dbfield,
+            labels=self.get_field_labels()
+        )
+
+
+class ModelCoreResourceMixin(FieldPermissionViewMixin, CoreResourceMixin, PermissionsModelCoreResourceMixin):
 
     DEFAULT_REST_CONTEXT_MAPPING = {
         **BaseResource.DEFAULT_REST_CONTEXT_MAPPING,
         'request_count': ('HTTP_X_REQUEST_COUNT', '_request_count'),
+        'direction': ('HTTP_X_DIRECTION', '_direction'),
+        'order': ('HTTP_X_ORDER', '_order')
     }
 
+    field_labels = None
+    filters = {}
+
+    def _get_queryset(self):
+        return self.core.get_queryset(self.request)
+
     def get_allowed_fields_rfs(self, obj=None):
         return super().get_allowed_fields_rfs().subtract(self._get_disallowed_fields_from_permissions(obj=obj))
 
+    def get_fields(self, obj=None):
+        fields = list(self.fields) if self.fields is not None else None
+        return self.core.get_rest_fields(self.request, obj=None) if fields is None else fields
+
+    def get_default_fields(self, obj=None):
+        default_fields = list(self.default_fields) if self.default_fields is not None else None
+        return self.core.get_rest_default_fields(self.request, obj=None) if default_fields is None else default_fields
+
+    def get_detailed_fields(self, obj=None):
+        detailed_fields = list(self.detailed_fields) if self.detailed_fields is not None else self.get_fields(obj=obj)
+        return self.core.get_rest_detailed_fields(self.request, obj=obj) if detailed_fields is None else detailed_fields
+
+    def get_general_fields(self, obj=None):
+        general_fields = list(self.general_fields) if self.general_fields is not None else self.get_fields(obj=obj)
+        return self.core.get_rest_general_fields(self.request, obj=obj) if general_fields is None else general_fields
+
+    def get_guest_fields(self, obj=None):
+        guest_fields = list(self.guest_fields) if self.guest_fields is not None else None
+        return self.core.get_rest_guest_fields(self.request, obj=obj) if guest_fields is None else guest_fields
+
+    def get_extra_fields(self, obj=None):
+        extra_fields = list(self.extra_fields) if self.extra_fields is not None else None
+        return self.core.get_rest_extra_fields(self.request) if extra_fields is None else extra_fields
+
+    def get_extra_filter_fields(self):
+        extra_filter_fields = list(self.extra_filter_fields) if self.extra_filter_fields is not None else None
+        return (
+            self.core.get_rest_extra_filter_fields(self.request) if extra_filter_fields is None else extra_filter_fields
+        )
+
+    def get_filter_fields(self):
+        filter_fields = list(self.filter_fields) if self.filter_fields is not None else None
+        return self.core.get_rest_filter_fields(self.request) if filter_fields is None else filter_fields
+
+    def get_extra_order_fields(self):
+        extra_order_fields = list(self.extra_order_fields) if self.extra_order_fields is not None else None
+        return self.core.get_rest_extra_order_fields(self.request) if extra_order_fields is None else extra_order_fields
+
+    def get_order_fields(self):
+        order_fields = list(self.order_fields) if self.order_fields is not None else None
+        return self.core.get_rest_order_fields(self.request) if order_fields is None else order_fields
+
     def get_field_labels(self):
         return (
             self.field_labels if self.field_labels is not None else self.core.get_rest_field_labels(self.request)
@@ -290,77 +337,22 @@ class RESTModelResource(FieldPermissionViewMixin, RESTModelCoreMixin, RESTResour
             field_labels=self.get_field_labels()
         )
 
-    def get_fields(self, obj=None):
-        fields = super(DefaultRESTModelResource, self).get_fields(obj=obj)
-        return self.core.get_rest_fields(self.request, obj=None) if fields is None else fields
-
-    def get_detailed_fields(self, obj=None):
-        detailed_fields = super(DefaultRESTModelResource, self).get_detailed_fields(obj=obj)
-        return self.core.get_rest_detailed_fields(self.request, obj=obj) if detailed_fields is None else detailed_fields
-
-    def get_general_fields(self, obj=None):
-        general_fields = super(DefaultRESTModelResource, self).get_general_fields(obj=obj)
-        return self.core.get_rest_general_fields(self.request, obj=obj) if general_fields is None else general_fields
-
-    def get_guest_fields(self, obj=None):
-        guest_fields = super(DefaultRESTModelResource, self).get_guest_fields(obj=obj)
-        return self.core.get_rest_guest_fields(self.request, obj=obj) if guest_fields is None else guest_fields
-
-    def get_extra_fields(self, obj=None):
-        extra_fields = super(DefaultRESTModelResource, self).get_extra_fields(obj=obj)
-        return self.core.get_rest_extra_fields(self.request) if extra_fields is None else extra_fields
-
-    def get_default_fields(self, obj=None):
-        default_fields = super(DefaultRESTModelResource, self).get_default_fields(obj=obj)
-        return self.core.get_rest_default_fields(self.request, obj=None) if default_fields is None else default_fields
-
-    def get_extra_filter_fields(self):
-        extra_filter_fields = super(DefaultRESTModelResource, self).get_extra_filter_fields()
-        return self.core.get_rest_extra_filter_fields(self.request) if extra_filter_fields is None else extra_filter_fields
-
-    def get_filter_fields(self):
-        filter_fields = super(DefaultRESTModelResource, self).get_filter_fields()
-        return self.core.get_rest_filter_fields(self.request) if filter_fields is None else filter_fields
-
-    def get_extra_order_fields(self):
-        extra_order_fields = super(DefaultRESTModelResource, self).get_extra_order_fields()
-        return self.core.get_rest_extra_order_fields(self.request) if extra_order_fields is None else extra_order_fields
-
-    def get_order_fields(self):
-        order_fields = super(DefaultRESTModelResource, self).get_order_fields()
-        return self.core.get_rest_order_fields(self.request) if order_fields is None else order_fields
-
-    def get_default_fields_rfs(self, obj=None):
-        return super(RESTModelResource, self).get_default_fields_rfs(obj=obj).join(
-            rfs(self.get_default_fields_extension(obj))
-        )
-
-    def get_default_fields_extension(self, obj=None):
-        return (
-            self.core.get_rest_default_fields_extension(self.request, obj=None)
-            if self.default_fields_extension is None else self.default_fields_extension
-        )
-
-    def get_queryset(self):
-        return self.core.get_queryset(self.request)
-
-    def _get_headers_queryset_context_mapping(self):
-        mapping = super(RESTModelResource, self)._get_headers_queryset_context_mapping()
-        mapping.update({
-            'direction': ('HTTP_X_DIRECTION', '_direction'),
-            'order': ('HTTP_X_ORDER', '_order')
-        })
-        return mapping
-
-    def _preload_queryset(self, qs):
-        return self.core.preload_queryset(self.request, qs)
-
     def _get_exclude(self, obj=None):
         return (
             list(self.core.get_rest_form_exclude(self.request, obj))
             + list(self._get_readonly_fields_from_permissions(obj))
         )
 
+
+class DjangoCoreResource(ModelCoreResourceMixin, SmartFormDjangoResource):
+
+    form_class = None
+    abstract = True
+    filter_manager = CoreDjangoFilterManager()
+
+    def _preload_queryset(self, qs):
+        return self.core.preload_queryset(self.request, qs)
+
     def _get_form_fields(self, obj=None):
         return self.core.get_rest_form_fields(self.request, obj)
 
@@ -395,38 +387,26 @@ class RESTModelResource(FieldPermissionViewMixin, RESTModelCoreMixin, RESTResour
     def _post_delete_obj(self, obj):
         self.core.post_delete_model(self.request, obj)
 
-    def _generate_form_class(self, inst, exclude=[]):
-        form_class = self._get_form_class(inst)
-        exclude = list(self._get_exclude(inst)) + exclude
-        fields = self._get_form_fields(inst)
-        if hasattr(form_class, '_meta') and form_class._meta.exclude:
-            exclude.extend(form_class._meta.exclude)
-        return rest_modelform_factory(self.model, form=form_class, form_factory=smartmodelform_factory,
-                                      auto_related_direct_fields=pyston_settings.AUTO_RELATED_DIRECT_FIELDS,
-                                      auto_related_reverse_fields=pyston_settings.AUTO_RELATED_REVERSE_FIELDS,
-                                      request=self.request, exclude=exclude, fields=fields,
-                                      labels=self.get_field_labels())
-
     def put(self):
         # TODO: backward compatibility for bulk update should be used only patch
-        return super(RESTModelResource, self).put() if self.kwargs.get(self.pk_name) else self.update_bulk()
+        return super().put() if self.kwargs.get(self.pk_name) else self.update_bulk()
 
     def patch(self):
-        return super(RESTModelResource, self).patch() if self.kwargs.get(self.pk_name) else self.update_bulk()
+        return super().patch() if self.kwargs.get(self.pk_name) else self.update_bulk()
 
     @transaction.smart_atomic
     def update_bulk(self):
         qs = self._filter_queryset(self._get_queryset())
-        BULK_CHANGE_LIMIT = getattr(settings, 'BULK_CHANGE_LIMIT', 200)
+        BULK_CHANGE_LIMIT = getattr(django_settings, 'BULK_CHANGE_LIMIT', 200)
         if qs.count() > BULK_CHANGE_LIMIT:
-            return RESTErrorResponse(
+            return RestErrorResponse(
                 msg=ugettext('Only %s objects can be changed by one request').format(BULK_CHANGE_LIMIT),
                 code=413)
 
         data = self.get_dict_data()
         objects, errors = zip(*(self._update_obj(obj, data) for obj in qs))
         compact_errors = tuple(err for err in errors if err)
-        return RESTErrorsResponse(compact_errors) if len(compact_errors) > 0 else objects
+        return RestErrorsResponse(compact_errors) if len(compact_errors) > 0 else objects
 
     def _update_obj(self, obj, data):
         try:
@@ -441,12 +421,9 @@ class RESTModelResource(FieldPermissionViewMixin, RESTModelCoreMixin, RESTResour
             return (None, self._format_message(obj, ex))
         except (ConflictException, NotAllowedException):
             raise
-        except RESTException as ex:
+        except RestException as ex:
             return (None, self._format_message(obj, ex))
 
-    def _extract_message(self, ex):
-        return '\n'.join([force_text(v) for v in ex.errors.values()]) if hasattr(ex, 'errors') else ex.message
-
     def _format_message(self, obj, ex):
         return {
             'id': obj.pk,
